/*
 * $Id: DataWarehouse.java 13605 2008-12-10 19:00:15Z tcarlson $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.example.bookstore;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;

import org.mule.example.bookstore.web.HtmlTemplate;

/**
 * Tracks statistics on book orders.
 */
public class DataWarehouse
{
    int booksOrdered = 0;
    double totalRevenue = 0;
    double averagePrice = 0;
    Map <String, Integer> sales = new HashMap <String, Integer> ();
    String bestSeller = "";
    
    public String updateStats(Order order)
    {
        Book book = order.getBook();
        booksOrdered += order.getQuantity();
        totalRevenue += (book.getPrice() * order.getQuantity());
        averagePrice = totalRevenue / booksOrdered;

        String title = book.getTitle();
        Integer quantity = sales.get(title);
        if (quantity == null)
        {
        	sales.put(title, order.getQuantity());
        }
        else
        {
        	sales.put(title, quantity + order.getQuantity());
        }
        bestSeller = getBestSeller();
        
        System.out.println("Updating stats");
        return HtmlTemplate.wrapHtmlBody(printHtmlStats());
    }

    protected String getBestSeller()
    {
    	String title = "";
    	int quantity = 0;
    	Iterator it = sales.entrySet().iterator();
    	Entry <String, Integer> entry;
    	while (it.hasNext())
    	{
    		entry = (Entry <String, Integer>) it.next();
    		if (entry.getValue() > quantity)
    		{
    			title = entry.getKey();
    			quantity = entry.getValue();
    		}    		
    	}
    	return title;
    }
    
    protected String printHtmlStats()
    {
        String output = "<h2>Data Warehouse Statistics</h2>";
        output += "<table>";
        output += "<tr><th>Books sold</th> <td>" + booksOrdered + "</td></tr>";
        output += "<tr><th>Total revenue</th> <td>$" + totalRevenue + "</td></tr>";
        output += "<tr><th>Average price</th> <td>$" + averagePrice + "</td></tr>";
        output += "<tr><th>Best seller</th> <td>" + bestSeller + "</td></tr>";
        output += "</table>";
        return output;
    }
}


